@@ -1,5 +1,5 @@
 test_that("ard_continuous_ci.data.frame(method = 't.test')", {
-  skip_if_not(is_pkg_installed("broom", reference_pkg = "cardx"))
+  skip_if_not(is_pkg_installed("broom"))
 
   expect_equal(
     ard_continuous_ci(
@@ -17,7 +17,7 @@ test_that("ard_continuous_ci.data.frame(method = 't.test')", {
 })
 
 test_that("ard_continuous_ci.data.frame(method = 'wilcox.test')", {
-  skip_if_not(is_pkg_installed("broom", reference_pkg = "cardx"))
+  skip_if_not(is_pkg_installed("broom"))
   expect_equal(
     ard_continuous_ci(
       mtcars,
@@ -35,7 +35,7 @@ test_that("ard_continuous_ci.data.frame(method = 'wilcox.test')", {
 })
 
 test_that("ard_continuous_ci.data.frame() follows ard structure", {
-  skip_if_not(is_pkg_installed("broom", reference_pkg = "cardx"))
+  skip_if_not(is_pkg_installed("broom"))
 
   expect_silent(
     ard_continuous_ci(
